JupyterRelayHub
===============

.. currentmodule:: pywwt.jupyter_relay

.. autoclass:: JupyterRelayHub
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~JupyterRelayHub.get_static_files_url
      ~JupyterRelayHub.serve_file
      ~JupyterRelayHub.serve_tree

   .. rubric:: Methods Documentation

   .. automethod:: get_static_files_url
   .. automethod:: serve_file
   .. automethod:: serve_tree
